@@ -63,7 +63,7 @@ def get_scopes(tenant_id=None):
                 return abort(500, "INTERNAL SERVER ERROR")
         else:
             if host:
-                roles = get_platform_roles()
+                roles = get_platform_roles(host)
                 scopes = []
                 for role in roles:
                     if role['name'] in user_roles:
@@ -82,7 +82,7 @@ def get_user_roles(host):
     return roles
 
 
-def get_platform_roles():
+def get_platform_roles(host):
     response = requests.get(host+'/roles/platform')
     roles = json.loads(response.text)
 
